
#ifndef _C1_ba39_
#define _C1_ba39_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F53_999(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit39(void);
extern void F386_5694(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
